@@ -24,6 +24,8 @@ def options_config():
     parser.add_option("-b", "--base", dest="base_observation_threshold", type=int, default=25,
                       help="minimum number of observations kept for "
                            "each query ignoring the filter threshold.", metavar="NUMBER")
+    parser.add_option("-V", "--overlap", dest="minimum_alignment_overlap", type=float, default=0.001,
+                      help="minimum fraction of nongap sites needed for a valid pairwise distance.", metavar="NUMBER")
     parser.add_option("-X", "--mask", dest="mask_lowconfidence", action='store_true', default=False,
                       help="masks low confidence characters in the alignments indicated by lowercase characters "
                            "output by softwares like SEPP.")
